#include <SPI.h>
#include <Wire.h>
#include <Adafruit_GFX.h>
#include <Adafruit_SSD1306.h>

#define SCREEN_WIDTH 128    // OLED kijelző szélessége képpontokban
#define SCREEN_HEIGHT 32    // OLED kijelző magassága képpontokban
#define OLED_RESET     -1   // -1 jelentése: nincs RESET kivezetés
#define SCREEN_ADDRESS 0x3C // A kijelző I2C címe (jobbra igazítva)
Adafruit_SSD1306 display(SCREEN_WIDTH, SCREEN_HEIGHT, &Wire, OLED_RESET);

#define PUSH2 2             // Nyomógomb
#define L_sense A0
#define L_LED   10
#define F_sense A1
#define F_LED    9
#define NMEAS   50
boolean waitforpress = true;
uint32_t l_limit = 100;
uint32_t l_limit_min = 80;
uint32_t f_limit = 100;
uint32_t f_limit_min = 80;


uint32_t meres(int p_sense, int p_LED) {
  uint32_t sum0, sum1;
  digitalWrite(p_LED, LOW);
  sum0 = 0;
  for (int i = 0; i < NMEAS; i++) {
    sum0 += analogRead(p_sense);
  }
  digitalWrite(p_LED, HIGH);
  sum1 = 0;
  for (int i = 0; i < NMEAS; i++) {
    sum1 += analogRead(p_sense);
  }
  if (sum0 > sum1) sum0 = sum1;
  return ((sum1 - sum0) / NMEAS);
}

void setup() {
  Serial.begin(9600);
  display.begin(SSD1306_SWITCHCAPVCC, SCREEN_ADDRESS);
  display.display();
  pinMode(PUSH2, INPUT_PULLUP);
  pinMode(L_LED, OUTPUT);
  pinMode(F_LED, OUTPUT);
  delay(2000);              // Pause for 2 seconds
  l_limit = get_parameter("L_MAX", L_sense, L_LED);
  Serial.print("\r\nL_MAX = ");
  Serial.print(l_limit);
  l_limit_min = get_parameter("L_MIN", L_sense, L_LED);
  Serial.print("\r\nL_MIN = ");
  Serial.print(l_limit_min);
  f_limit = get_parameter("F_MAX", F_sense, F_LED);
  Serial.print("\r\nF_MAX = ");
  Serial.print(f_limit);
  f_limit_min = get_parameter("F_MIN", F_sense, F_LED);
  Serial.print("\r\nF_MIN = ");
  Serial.print(f_limit_min);
}

void loop() {

}


uint32_t get_parameter(char* txt, int p_sense, int p_led) {
  uint32_t mypar;
  while (waitforpress) {           // Ha lenyomásra várunk és
    mypar = meres(p_sense, p_led);
    display.clearDisplay();
    display.setTextSize(2);             // Normal 2:1 pixel scale
    display.setTextColor(SSD1306_WHITE);        // Draw white text
    display.setCursor(0, 0);            // Start at top-left corner
    display.println(txt);
    display.setCursor(0, 16);            // Start at middle-left position
    display.println(mypar);
    display.display();
    if (!digitalRead(PUSH2)) {   // Ha lenyomás történt...
      waitforpress = false;      // Következő stáció: felengedésre várunk
    }
  }
  delay(20);                     // Pergésmentesítő késleltetés
  while (!waitforpress) {
    if (digitalRead(PUSH2)) {    // Ha felengedést észlelünk...
      waitforpress = true;       // Következő stáció: lenyomásra várunk
    }
  }
  delay(20);                     // Pergésmentesítő késleltetés
  return mypar;
}
